import { spawn, spawnSync } from 'child_process';

export const checkPnpm = () => {
  try {
    spawnSync('pnpm', ['--version']);
    return true;
  } catch (e) {
    return false;
  }
};

type InstallDepsOptions = {
  appPath: string;
  isProduction?: boolean;
  sync?: boolean;
};
export const installDeps = (opts: InstallDepsOptions) => {
  const { appPath } = opts;
  const isProduction = opts.isProduction ?? true;
  const params = ['i'];
  if (isProduction) {
    params.push('--production');
  }
  const syncSpawn = opts.sync ? spawnSync : spawn;
  if (checkPnpm()) {
    syncSpawn('pnpm', params, { cwd: appPath, stdio: 'inherit', env: process.env });
  } else {
    syncSpawn('npm', params, { cwd: appPath, stdio: 'inherit', env: process.env });
  }
};
